from distutils.core import setup

setup(
    name = "name_nester",
    version = "0.0.3",
    py_modules = ["nester"],
    author = "liulei",
    author_email = "liulei237136@gmail.com",
    url = "http://boocer.com",
    description = "A simple printer of nested lists"
)
